
#ifndef VTKPVVTKEXTENSIONSIOGENERAL_EXPORT_H
#define VTKPVVTKEXTENSIONSIOGENERAL_EXPORT_H

#ifdef VTKPVVTKEXTENSIONSIOGENERAL_STATIC_DEFINE
#  define VTKPVVTKEXTENSIONSIOGENERAL_EXPORT
#  define VTKPVVTKEXTENSIONSIOGENERAL_NO_EXPORT
#else
#  ifndef VTKPVVTKEXTENSIONSIOGENERAL_EXPORT
#    ifdef VTKExtensionsIOGeneral_EXPORTS
        /* We are building this library */
#      define VTKPVVTKEXTENSIONSIOGENERAL_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define VTKPVVTKEXTENSIONSIOGENERAL_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef VTKPVVTKEXTENSIONSIOGENERAL_NO_EXPORT
#    define VTKPVVTKEXTENSIONSIOGENERAL_NO_EXPORT 
#  endif
#endif

#ifndef VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED
#  define VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED __declspec(deprecated)
#endif

#ifndef VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED_EXPORT
#  define VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSIOGENERAL_EXPORT VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED
#endif

#ifndef VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED_NO_EXPORT
#  define VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSIOGENERAL_NO_EXPORT VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVVTKEXTENSIONSIOGENERAL_NO_DEPRECATED
#    define VTKPVVTKEXTENSIONSIOGENERAL_NO_DEPRECATED
#  endif
#endif

#endif /* VTKPVVTKEXTENSIONSIOGENERAL_EXPORT_H */
