
#ifndef VTKREMOTINGVIEWSPYTHON_EXPORT_H
#define VTKREMOTINGVIEWSPYTHON_EXPORT_H

#ifdef VTKREMOTINGVIEWSPYTHON_STATIC_DEFINE
#  define VTKREMOTINGVIEWSPYTHON_EXPORT
#  define VTKREMOTINGVIEWSPYTHON_NO_EXPORT
#else
#  ifndef VTKREMOTINGVIEWSPYTHON_EXPORT
#    ifdef RemotingViewsPython_EXPORTS
        /* We are building this library */
#      define VTKREMOTINGVIEWSPYTHON_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define VTKREMOTINGVIEWSPYTHON_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef VTKREMOTINGVIEWSPYTHON_NO_EXPORT
#    define VTKREMOTINGVIEWSPYTHON_NO_EXPORT 
#  endif
#endif

#ifndef VTKREMOTINGVIEWSPYTHON_DEPRECATED
#  define VTKREMOTINGVIEWSPYTHON_DEPRECATED __declspec(deprecated)
#endif

#ifndef VTKREMOTINGVIEWSPYTHON_DEPRECATED_EXPORT
#  define VTKREMOTINGVIEWSPYTHON_DEPRECATED_EXPORT VTKREMOTINGVIEWSPYTHON_EXPORT VTKREMOTINGVIEWSPYTHON_DEPRECATED
#endif

#ifndef VTKREMOTINGVIEWSPYTHON_DEPRECATED_NO_EXPORT
#  define VTKREMOTINGVIEWSPYTHON_DEPRECATED_NO_EXPORT VTKREMOTINGVIEWSPYTHON_NO_EXPORT VTKREMOTINGVIEWSPYTHON_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKREMOTINGVIEWSPYTHON_NO_DEPRECATED
#    define VTKREMOTINGVIEWSPYTHON_NO_DEPRECATED
#  endif
#endif

#endif /* VTKREMOTINGVIEWSPYTHON_EXPORT_H */
