
#ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT_H
#define VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT_H

#ifdef VTKPVVTKEXTENSIONSFILTERSPYTHON_STATIC_DEFINE
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_EXPORT
#else
#  ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT
#    ifdef VTKExtensionsFiltersPython_EXPORTS
        /* We are building this library */
#      define VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_EXPORT
#    define VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_EXPORT 
#  endif
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED __declspec(deprecated)
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED_NO_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_EXPORT VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_DEPRECATED
#    define VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_DEPRECATED
#  endif
#endif

#endif /* VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT_H */
