
#ifndef VTKFILTERSHYPERTREEGRIDADR_EXPORT_H
#define VTKFILTERSHYPERTREEGRIDADR_EXPORT_H

#ifdef VTKFILTERSHYPERTREEGRIDADR_STATIC_DEFINE
#  define VTKFILTERSHYPERTREEGRIDADR_EXPORT
#  define VTKFILTERSHYPERTREEGRIDADR_NO_EXPORT
#else
#  ifndef VTKFILTERSHYPERTREEGRIDADR_EXPORT
#    ifdef HyperTreeGridFilters_EXPORTS
        /* We are building this library */
#      define VTKFILTERSHYPERTREEGRIDADR_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define VTKFILTERSHYPERTREEGRIDADR_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef VTKFILTERSHYPERTREEGRIDADR_NO_EXPORT
#    define VTKFILTERSHYPERTREEGRIDADR_NO_EXPORT 
#  endif
#endif

#ifndef VTKFILTERSHYPERTREEGRIDADR_DEPRECATED
#  define VTKFILTERSHYPERTREEGRIDADR_DEPRECATED __declspec(deprecated)
#endif

#ifndef VTKFILTERSHYPERTREEGRIDADR_DEPRECATED_EXPORT
#  define VTKFILTERSHYPERTREEGRIDADR_DEPRECATED_EXPORT VTKFILTERSHYPERTREEGRIDADR_EXPORT VTKFILTERSHYPERTREEGRIDADR_DEPRECATED
#endif

#ifndef VTKFILTERSHYPERTREEGRIDADR_DEPRECATED_NO_EXPORT
#  define VTKFILTERSHYPERTREEGRIDADR_DEPRECATED_NO_EXPORT VTKFILTERSHYPERTREEGRIDADR_NO_EXPORT VTKFILTERSHYPERTREEGRIDADR_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKFILTERSHYPERTREEGRIDADR_NO_DEPRECATED
#    define VTKFILTERSHYPERTREEGRIDADR_NO_DEPRECATED
#  endif
#endif

#endif /* VTKFILTERSHYPERTREEGRIDADR_EXPORT_H */
