
#ifndef VTKNONORTHOGONALSOURCES_EXPORT_H
#define VTKNONORTHOGONALSOURCES_EXPORT_H

#ifdef VTKNONORTHOGONALSOURCES_STATIC_DEFINE
#  define VTKNONORTHOGONALSOURCES_EXPORT
#  define VTKNONORTHOGONALSOURCES_NO_EXPORT
#else
#  ifndef VTKNONORTHOGONALSOURCES_EXPORT
#    ifdef vtkNonOrthogonalSources_EXPORTS
        /* We are building this library */
#      define VTKNONORTHOGONALSOURCES_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define VTKNONORTHOGONALSOURCES_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef VTKNONORTHOGONALSOURCES_NO_EXPORT
#    define VTKNONORTHOGONALSOURCES_NO_EXPORT 
#  endif
#endif

#ifndef VTKNONORTHOGONALSOURCES_DEPRECATED
#  define VTKNONORTHOGONALSOURCES_DEPRECATED __declspec(deprecated)
#endif

#ifndef VTKNONORTHOGONALSOURCES_DEPRECATED_EXPORT
#  define VTKNONORTHOGONALSOURCES_DEPRECATED_EXPORT VTKNONORTHOGONALSOURCES_EXPORT VTKNONORTHOGONALSOURCES_DEPRECATED
#endif

#ifndef VTKNONORTHOGONALSOURCES_DEPRECATED_NO_EXPORT
#  define VTKNONORTHOGONALSOURCES_DEPRECATED_NO_EXPORT VTKNONORTHOGONALSOURCES_NO_EXPORT VTKNONORTHOGONALSOURCES_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKNONORTHOGONALSOURCES_NO_DEPRECATED
#    define VTKNONORTHOGONALSOURCES_NO_DEPRECATED
#  endif
#endif

#endif /* VTKNONORTHOGONALSOURCES_EXPORT_H */
